---
title: مراحل
next: /docs/guide/deploy-site
---

یک کامپوننت داخلی برای نمایش یک سری مراحل.

## مثال

{{% steps %}}

### مرحله ۱
این اولین مرحله است.

### مرحله ۲

این دومین مرحله است.

### مرحله ۳

این سومین مرحله است.

{{% /steps %}}


## استفاده

سرتیتر مارک‌داون h3 را در کد کوتاه `steps` قرار دهید.

```
{{%/* steps */%}}

### مرحله ۱

این اولین مرحله است.

### مرحله ۲

این دومین مرحله است.

{{%/* /steps */%}}
```
